@@ -15,14 +15,17 @@ namespace Botan {
 /**
 * EME from PKCS #1 v1.5
 */
-class BOTAN_DLL EME_PKCS1v15 : public EME
+class BOTAN_DLL EME_PKCS1v15 final : public EME
    {
    public:
       size_t maximum_input_size(size_t) const override;
    private:
       secure_vector<byte> pad(const byte[], size_t, size_t,
                              RandomNumberGenerator&) const override;
-      secure_vector<byte> unpad(const byte[], size_t, size_t) const override;
+
+      secure_vector<byte> unpad(byte& valid_mask,
+                                const byte in[],
+                                size_t in_len) const override;
    };
 
 }
