@@ -30,7 +30,7 @@ class BOTAN_DLL Serpent : public Block_Cipher_Fixed_Params<16, 16, 32, 8>
       * @return const reference to the key schedule
       */
       const secure_vector<u32bit>& get_round_keys() const
-         { return round_key; }
+         { return m_round_key; }
 
       /**
       * For use by subclasses that implement the key schedule
@@ -38,12 +38,12 @@ class BOTAN_DLL Serpent : public Block_Cipher_Fixed_Params<16, 16, 32, 8>
       */
       void set_round_keys(const u32bit ks[132])
          {
-         round_key.assign(&ks[0], &ks[132]);
+         m_round_key.assign(&ks[0], &ks[132]);
          }
 
    private:
       void key_schedule(const byte key[], size_t length) override;
-      secure_vector<u32bit> round_key;
+      secure_vector<u32bit> m_round_key;
    };
 
 }
